from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNKNOWN: _ClassVar[Scheme]
    HTTP: _ClassVar[Scheme]
    HTTPS: _ClassVar[Scheme]
    WS: _ClassVar[Scheme]
    WSS: _ClassVar[Scheme]
UNKNOWN: Scheme
HTTP: Scheme
HTTPS: Scheme
WS: Scheme
WSS: Scheme

class Swagger(_message.Message):
    __slots__ = ["swagger", "info", "host", "base_path", "schemes", "consumes", "produces", "responses", "security_definitions", "security", "tags", "external_docs", "extensions"]
    class ResponsesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Response
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Response, _Mapping]] = ...) -> None: ...
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    SWAGGER_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    BASE_PATH_FIELD_NUMBER: _ClassVar[int]
    SCHEMES_FIELD_NUMBER: _ClassVar[int]
    CONSUMES_FIELD_NUMBER: _ClassVar[int]
    PRODUCES_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    SECURITY_DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    swagger: str
    info: Info
    host: str
    base_path: str
    schemes: _containers.RepeatedScalarFieldContainer[Scheme]
    consumes: _containers.RepeatedScalarFieldContainer[str]
    produces: _containers.RepeatedScalarFieldContainer[str]
    responses: _containers.MessageMap[str, Response]
    security_definitions: SecurityDefinitions
    security: _containers.RepeatedCompositeFieldContainer[SecurityRequirement]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    external_docs: ExternalDocumentation
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, swagger: _Optional[str] = ..., info: _Optional[_Union[Info, _Mapping]] = ..., host: _Optional[str] = ..., base_path: _Optional[str] = ..., schemes: _Optional[_Iterable[_Union[Scheme, str]]] = ..., consumes: _Optional[_Iterable[str]] = ..., produces: _Optional[_Iterable[str]] = ..., responses: _Optional[_Mapping[str, Response]] = ..., security_definitions: _Optional[_Union[SecurityDefinitions, _Mapping]] = ..., security: _Optional[_Iterable[_Union[SecurityRequirement, _Mapping]]] = ..., tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ..., external_docs: _Optional[_Union[ExternalDocumentation, _Mapping]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class Operation(_message.Message):
    __slots__ = ["tags", "summary", "description", "external_docs", "operation_id", "consumes", "produces", "responses", "schemes", "deprecated", "security", "extensions", "parameters"]
    class ResponsesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Response
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Response, _Mapping]] = ...) -> None: ...
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    TAGS_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    CONSUMES_FIELD_NUMBER: _ClassVar[int]
    PRODUCES_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    SCHEMES_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedScalarFieldContainer[str]
    summary: str
    description: str
    external_docs: ExternalDocumentation
    operation_id: str
    consumes: _containers.RepeatedScalarFieldContainer[str]
    produces: _containers.RepeatedScalarFieldContainer[str]
    responses: _containers.MessageMap[str, Response]
    schemes: _containers.RepeatedScalarFieldContainer[Scheme]
    deprecated: bool
    security: _containers.RepeatedCompositeFieldContainer[SecurityRequirement]
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    parameters: Parameters
    def __init__(self, tags: _Optional[_Iterable[str]] = ..., summary: _Optional[str] = ..., description: _Optional[str] = ..., external_docs: _Optional[_Union[ExternalDocumentation, _Mapping]] = ..., operation_id: _Optional[str] = ..., consumes: _Optional[_Iterable[str]] = ..., produces: _Optional[_Iterable[str]] = ..., responses: _Optional[_Mapping[str, Response]] = ..., schemes: _Optional[_Iterable[_Union[Scheme, str]]] = ..., deprecated: bool = ..., security: _Optional[_Iterable[_Union[SecurityRequirement, _Mapping]]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ..., parameters: _Optional[_Union[Parameters, _Mapping]] = ...) -> None: ...

class Parameters(_message.Message):
    __slots__ = ["headers"]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    headers: _containers.RepeatedCompositeFieldContainer[HeaderParameter]
    def __init__(self, headers: _Optional[_Iterable[_Union[HeaderParameter, _Mapping]]] = ...) -> None: ...

class HeaderParameter(_message.Message):
    __slots__ = ["name", "description", "type", "format", "required"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[HeaderParameter.Type]
        STRING: _ClassVar[HeaderParameter.Type]
        NUMBER: _ClassVar[HeaderParameter.Type]
        INTEGER: _ClassVar[HeaderParameter.Type]
        BOOLEAN: _ClassVar[HeaderParameter.Type]
    UNKNOWN: HeaderParameter.Type
    STRING: HeaderParameter.Type
    NUMBER: HeaderParameter.Type
    INTEGER: HeaderParameter.Type
    BOOLEAN: HeaderParameter.Type
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    type: HeaderParameter.Type
    format: str
    required: bool
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., type: _Optional[_Union[HeaderParameter.Type, str]] = ..., format: _Optional[str] = ..., required: bool = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ["description", "type", "format", "default", "pattern"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    description: str
    type: str
    format: str
    default: str
    pattern: str
    def __init__(self, description: _Optional[str] = ..., type: _Optional[str] = ..., format: _Optional[str] = ..., default: _Optional[str] = ..., pattern: _Optional[str] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ["description", "schema", "headers", "examples", "extensions"]
    class HeadersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Header
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Header, _Mapping]] = ...) -> None: ...
    class ExamplesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    description: str
    schema: Schema
    headers: _containers.MessageMap[str, Header]
    examples: _containers.ScalarMap[str, str]
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, description: _Optional[str] = ..., schema: _Optional[_Union[Schema, _Mapping]] = ..., headers: _Optional[_Mapping[str, Header]] = ..., examples: _Optional[_Mapping[str, str]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class Info(_message.Message):
    __slots__ = ["title", "description", "terms_of_service", "contact", "license", "version", "extensions"]
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TERMS_OF_SERVICE_FIELD_NUMBER: _ClassVar[int]
    CONTACT_FIELD_NUMBER: _ClassVar[int]
    LICENSE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    terms_of_service: str
    contact: Contact
    license: License
    version: str
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., terms_of_service: _Optional[str] = ..., contact: _Optional[_Union[Contact, _Mapping]] = ..., license: _Optional[_Union[License, _Mapping]] = ..., version: _Optional[str] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class Contact(_message.Message):
    __slots__ = ["name", "url", "email"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    name: str
    url: str
    email: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class License(_message.Message):
    __slots__ = ["name", "url"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    name: str
    url: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class ExternalDocumentation(_message.Message):
    __slots__ = ["description", "url"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    description: str
    url: str
    def __init__(self, description: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ["json_schema", "discriminator", "read_only", "external_docs", "example"]
    JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    DISCRIMINATOR_FIELD_NUMBER: _ClassVar[int]
    READ_ONLY_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    json_schema: JSONSchema
    discriminator: str
    read_only: bool
    external_docs: ExternalDocumentation
    example: str
    def __init__(self, json_schema: _Optional[_Union[JSONSchema, _Mapping]] = ..., discriminator: _Optional[str] = ..., read_only: bool = ..., external_docs: _Optional[_Union[ExternalDocumentation, _Mapping]] = ..., example: _Optional[str] = ...) -> None: ...

class JSONSchema(_message.Message):
    __slots__ = ["ref", "title", "description", "default", "read_only", "example", "multiple_of", "maximum", "exclusive_maximum", "minimum", "exclusive_minimum", "max_length", "min_length", "pattern", "max_items", "min_items", "unique_items", "max_properties", "min_properties", "required", "array", "type", "format", "enum", "field_configuration", "extensions"]
    class JSONSchemaSimpleTypes(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        ARRAY: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        BOOLEAN: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        INTEGER: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        NULL: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        NUMBER: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        OBJECT: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
        STRING: _ClassVar[JSONSchema.JSONSchemaSimpleTypes]
    UNKNOWN: JSONSchema.JSONSchemaSimpleTypes
    ARRAY: JSONSchema.JSONSchemaSimpleTypes
    BOOLEAN: JSONSchema.JSONSchemaSimpleTypes
    INTEGER: JSONSchema.JSONSchemaSimpleTypes
    NULL: JSONSchema.JSONSchemaSimpleTypes
    NUMBER: JSONSchema.JSONSchemaSimpleTypes
    OBJECT: JSONSchema.JSONSchemaSimpleTypes
    STRING: JSONSchema.JSONSchemaSimpleTypes
    class FieldConfiguration(_message.Message):
        __slots__ = ["path_param_name"]
        PATH_PARAM_NAME_FIELD_NUMBER: _ClassVar[int]
        path_param_name: str
        def __init__(self, path_param_name: _Optional[str] = ...) -> None: ...
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    REF_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    READ_ONLY_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    MULTIPLE_OF_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_FIELD_NUMBER: _ClassVar[int]
    EXCLUSIVE_MAXIMUM_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_FIELD_NUMBER: _ClassVar[int]
    EXCLUSIVE_MINIMUM_FIELD_NUMBER: _ClassVar[int]
    MAX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MIN_LENGTH_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    MAX_ITEMS_FIELD_NUMBER: _ClassVar[int]
    MIN_ITEMS_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_ITEMS_FIELD_NUMBER: _ClassVar[int]
    MAX_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    MIN_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    FIELD_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    ref: str
    title: str
    description: str
    default: str
    read_only: bool
    example: str
    multiple_of: float
    maximum: float
    exclusive_maximum: bool
    minimum: float
    exclusive_minimum: bool
    max_length: int
    min_length: int
    pattern: str
    max_items: int
    min_items: int
    unique_items: bool
    max_properties: int
    min_properties: int
    required: _containers.RepeatedScalarFieldContainer[str]
    array: _containers.RepeatedScalarFieldContainer[str]
    type: _containers.RepeatedScalarFieldContainer[JSONSchema.JSONSchemaSimpleTypes]
    format: str
    enum: _containers.RepeatedScalarFieldContainer[str]
    field_configuration: JSONSchema.FieldConfiguration
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, ref: _Optional[str] = ..., title: _Optional[str] = ..., description: _Optional[str] = ..., default: _Optional[str] = ..., read_only: bool = ..., example: _Optional[str] = ..., multiple_of: _Optional[float] = ..., maximum: _Optional[float] = ..., exclusive_maximum: bool = ..., minimum: _Optional[float] = ..., exclusive_minimum: bool = ..., max_length: _Optional[int] = ..., min_length: _Optional[int] = ..., pattern: _Optional[str] = ..., max_items: _Optional[int] = ..., min_items: _Optional[int] = ..., unique_items: bool = ..., max_properties: _Optional[int] = ..., min_properties: _Optional[int] = ..., required: _Optional[_Iterable[str]] = ..., array: _Optional[_Iterable[str]] = ..., type: _Optional[_Iterable[_Union[JSONSchema.JSONSchemaSimpleTypes, str]]] = ..., format: _Optional[str] = ..., enum: _Optional[_Iterable[str]] = ..., field_configuration: _Optional[_Union[JSONSchema.FieldConfiguration, _Mapping]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class Tag(_message.Message):
    __slots__ = ["name", "description", "external_docs", "extensions"]
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    external_docs: ExternalDocumentation
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., external_docs: _Optional[_Union[ExternalDocumentation, _Mapping]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class SecurityDefinitions(_message.Message):
    __slots__ = ["security"]
    class SecurityEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: SecurityScheme
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[SecurityScheme, _Mapping]] = ...) -> None: ...
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    security: _containers.MessageMap[str, SecurityScheme]
    def __init__(self, security: _Optional[_Mapping[str, SecurityScheme]] = ...) -> None: ...

class SecurityScheme(_message.Message):
    __slots__ = ["type", "description", "name", "flow", "authorization_url", "token_url", "scopes", "extensions"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        TYPE_INVALID: _ClassVar[SecurityScheme.Type]
        TYPE_BASIC: _ClassVar[SecurityScheme.Type]
        TYPE_API_KEY: _ClassVar[SecurityScheme.Type]
        TYPE_OAUTH2: _ClassVar[SecurityScheme.Type]
    TYPE_INVALID: SecurityScheme.Type
    TYPE_BASIC: SecurityScheme.Type
    TYPE_API_KEY: SecurityScheme.Type
    TYPE_OAUTH2: SecurityScheme.Type
    class In(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        IN_INVALID: _ClassVar[SecurityScheme.In]
        IN_QUERY: _ClassVar[SecurityScheme.In]
        IN_HEADER: _ClassVar[SecurityScheme.In]
    IN_INVALID: SecurityScheme.In
    IN_QUERY: SecurityScheme.In
    IN_HEADER: SecurityScheme.In
    class Flow(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        FLOW_INVALID: _ClassVar[SecurityScheme.Flow]
        FLOW_IMPLICIT: _ClassVar[SecurityScheme.Flow]
        FLOW_PASSWORD: _ClassVar[SecurityScheme.Flow]
        FLOW_APPLICATION: _ClassVar[SecurityScheme.Flow]
        FLOW_ACCESS_CODE: _ClassVar[SecurityScheme.Flow]
    FLOW_INVALID: SecurityScheme.Flow
    FLOW_IMPLICIT: SecurityScheme.Flow
    FLOW_PASSWORD: SecurityScheme.Flow
    FLOW_APPLICATION: SecurityScheme.Flow
    FLOW_ACCESS_CODE: SecurityScheme.Flow
    class ExtensionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IN_FIELD_NUMBER: _ClassVar[int]
    FLOW_FIELD_NUMBER: _ClassVar[int]
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    EXTENSIONS_FIELD_NUMBER: _ClassVar[int]
    type: SecurityScheme.Type
    description: str
    name: str
    flow: SecurityScheme.Flow
    authorization_url: str
    token_url: str
    scopes: Scopes
    extensions: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, type: _Optional[_Union[SecurityScheme.Type, str]] = ..., description: _Optional[str] = ..., name: _Optional[str] = ..., flow: _Optional[_Union[SecurityScheme.Flow, str]] = ..., authorization_url: _Optional[str] = ..., token_url: _Optional[str] = ..., scopes: _Optional[_Union[Scopes, _Mapping]] = ..., extensions: _Optional[_Mapping[str, _struct_pb2.Value]] = ..., **kwargs) -> None: ...

class SecurityRequirement(_message.Message):
    __slots__ = ["security_requirement"]
    class SecurityRequirementValue(_message.Message):
        __slots__ = ["scope"]
        SCOPE_FIELD_NUMBER: _ClassVar[int]
        scope: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, scope: _Optional[_Iterable[str]] = ...) -> None: ...
    class SecurityRequirementEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: SecurityRequirement.SecurityRequirementValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[SecurityRequirement.SecurityRequirementValue, _Mapping]] = ...) -> None: ...
    SECURITY_REQUIREMENT_FIELD_NUMBER: _ClassVar[int]
    security_requirement: _containers.MessageMap[str, SecurityRequirement.SecurityRequirementValue]
    def __init__(self, security_requirement: _Optional[_Mapping[str, SecurityRequirement.SecurityRequirementValue]] = ...) -> None: ...

class Scopes(_message.Message):
    __slots__ = ["scope"]
    class ScopeEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    scope: _containers.ScalarMap[str, str]
    def __init__(self, scope: _Optional[_Mapping[str, str]] = ...) -> None: ...



# Copyright 2021-2023 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

from cerbos.sdk._async._grpc import (
    AdminCredentials,
    AsyncCerbosAdminClient,
    AsyncCerbosClient,
    AsyncPrincipalContext,
)
from cerbos.sdk._sync._grpc import CerbosAdminClient, CerbosClient, PrincipalContext

__all__ = [
    "AdminCredentials",
    "AsyncCerbosAdminClient",
    "AsyncCerbosClient",
    "AsyncPrincipalContext",
    "CerbosAdminClient",
    "CerbosClient",
    "PrincipalContext",
]



from cerbos.effect.v1 import effect_pb2 as _effect_pb2
from cerbos.schema.v1 import schema_pb2 as _schema_pb2
from google.api.expr.v1alpha1 import checked_pb2 as _checked_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2
from validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlanResourcesInput(_message.Message):
    __slots__ = ["request_id", "action", "principal", "resource", "aux_data", "include_meta"]
    class Resource(_message.Message):
        __slots__ = ["kind", "attr", "policy_version", "scope"]
        class AttrEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _struct_pb2.Value
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
        KIND_FIELD_NUMBER: _ClassVar[int]
        ATTR_FIELD_NUMBER: _ClassVar[int]
        POLICY_VERSION_FIELD_NUMBER: _ClassVar[int]
        SCOPE_FIELD_NUMBER: _ClassVar[int]
        kind: str
        attr: _containers.MessageMap[str, _struct_pb2.Value]
        policy_version: str
        scope: str
        def __init__(self, kind: _Optional[str] = ..., attr: _Optional[_Mapping[str, _struct_pb2.Value]] = ..., policy_version: _Optional[str] = ..., scope: _Optional[str] = ...) -> None: ...
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    AUX_DATA_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_META_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    action: str
    principal: Principal
    resource: PlanResourcesInput.Resource
    aux_data: AuxData
    include_meta: bool
    def __init__(self, request_id: _Optional[str] = ..., action: _Optional[str] = ..., principal: _Optional[_Union[Principal, _Mapping]] = ..., resource: _Optional[_Union[PlanResourcesInput.Resource, _Mapping]] = ..., aux_data: _Optional[_Union[AuxData, _Mapping]] = ..., include_meta: bool = ...) -> None: ...

class PlanResourcesAst(_message.Message):
    __slots__ = ["filter_ast"]
    class Node(_message.Message):
        __slots__ = ["logical_operation", "expression"]
        LOGICAL_OPERATION_FIELD_NUMBER: _ClassVar[int]
        EXPRESSION_FIELD_NUMBER: _ClassVar[int]
        logical_operation: PlanResourcesAst.LogicalOperation
        expression: _checked_pb2.CheckedExpr
        def __init__(self, logical_operation: _Optional[_Union[PlanResourcesAst.LogicalOperation, _Mapping]] = ..., expression: _Optional[_Union[_checked_pb2.CheckedExpr, _Mapping]] = ...) -> None: ...
    class LogicalOperation(_message.Message):
        __slots__ = ["operator", "nodes"]
        class Operator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            OPERATOR_UNSPECIFIED: _ClassVar[PlanResourcesAst.LogicalOperation.Operator]
            OPERATOR_AND: _ClassVar[PlanResourcesAst.LogicalOperation.Operator]
            OPERATOR_OR: _ClassVar[PlanResourcesAst.LogicalOperation.Operator]
            OPERATOR_NOT: _ClassVar[PlanResourcesAst.LogicalOperation.Operator]
        OPERATOR_UNSPECIFIED: PlanResourcesAst.LogicalOperation.Operator
        OPERATOR_AND: PlanResourcesAst.LogicalOperation.Operator
        OPERATOR_OR: PlanResourcesAst.LogicalOperation.Operator
        OPERATOR_NOT: PlanResourcesAst.LogicalOperation.Operator
        OPERATOR_FIELD_NUMBER: _ClassVar[int]
        NODES_FIELD_NUMBER: _ClassVar[int]
        operator: PlanResourcesAst.LogicalOperation.Operator
        nodes: _containers.RepeatedCompositeFieldContainer[PlanResourcesAst.Node]
        def __init__(self, operator: _Optional[_Union[PlanResourcesAst.LogicalOperation.Operator, str]] = ..., nodes: _Optional[_Iterable[_Union[PlanResourcesAst.Node, _Mapping]]] = ...) -> None: ...
    FILTER_AST_FIELD_NUMBER: _ClassVar[int]
    filter_ast: PlanResourcesAst.Node
    def __init__(self, filter_ast: _Optional[_Union[PlanResourcesAst.Node, _Mapping]] = ...) -> None: ...

class PlanResourcesFilter(_message.Message):
    __slots__ = ["kind", "condition"]
    class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        KIND_UNSPECIFIED: _ClassVar[PlanResourcesFilter.Kind]
        KIND_ALWAYS_ALLOWED: _ClassVar[PlanResourcesFilter.Kind]
        KIND_ALWAYS_DENIED: _ClassVar[PlanResourcesFilter.Kind]
        KIND_CONDITIONAL: _ClassVar[PlanResourcesFilter.Kind]
    KIND_UNSPECIFIED: PlanResourcesFilter.Kind
    KIND_ALWAYS_ALLOWED: PlanResourcesFilter.Kind
    KIND_ALWAYS_DENIED: PlanResourcesFilter.Kind
    KIND_CONDITIONAL: PlanResourcesFilter.Kind
    class Expression(_message.Message):
        __slots__ = ["operator", "operands"]
        class Operand(_message.Message):
            __slots__ = ["value", "expression", "variable"]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            EXPRESSION_FIELD_NUMBER: _ClassVar[int]
            VARIABLE_FIELD_NUMBER: _ClassVar[int]
            value: _struct_pb2.Value
            expression: PlanResourcesFilter.Expression
            variable: str
            def __init__(self, value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ..., expression: _Optional[_Union[PlanResourcesFilter.Expression, _Mapping]] = ..., variable: _Optional[str] = ...) -> None: ...
        OPERATOR_FIELD_NUMBER: _ClassVar[int]
        OPERANDS_FIELD_NUMBER: _ClassVar[int]
        operator: str
        operands: _containers.RepeatedCompositeFieldContainer[PlanResourcesFilter.Expression.Operand]
        def __init__(self, operator: _Optional[str] = ..., operands: _Optional[_Iterable[_Union[PlanResourcesFilter.Expression.Operand, _Mapping]]] = ...) -> None: ...
    KIND_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    kind: PlanResourcesFilter.Kind
    condition: PlanResourcesFilter.Expression.Operand
    def __init__(self, kind: _Optional[_Union[PlanResourcesFilter.Kind, str]] = ..., condition: _Optional[_Union[PlanResourcesFilter.Expression.Operand, _Mapping]] = ...) -> None: ...

class PlanResourcesOutput(_message.Message):
    __slots__ = ["request_id", "action", "kind", "policy_version", "scope", "filter", "filter_debug", "validation_errors"]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    POLICY_VERSION_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    FILTER_DEBUG_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_ERRORS_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    action: str
    kind: str
    policy_version: str
    scope: str
    filter: PlanResourcesFilter
    filter_debug: str
    validation_errors: _containers.RepeatedCompositeFieldContainer[_schema_pb2.ValidationError]
    def __init__(self, request_id: _Optional[str] = ..., action: _Optional[str] = ..., kind: _Optional[str] = ..., policy_version: _Optional[str] = ..., scope: _Optional[str] = ..., filter: _Optional[_Union[PlanResourcesFilter, _Mapping]] = ..., filter_debug: _Optional[str] = ..., validation_errors: _Optional[_Iterable[_Union[_schema_pb2.ValidationError, _Mapping]]] = ...) -> None: ...

class CheckInput(_message.Message):
    __slots__ = ["request_id", "resource", "principal", "actions", "aux_data"]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    AUX_DATA_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    resource: Resource
    principal: Principal
    actions: _containers.RepeatedScalarFieldContainer[str]
    aux_data: AuxData
    def __init__(self, request_id: _Optional[str] = ..., resource: _Optional[_Union[Resource, _Mapping]] = ..., principal: _Optional[_Union[Principal, _Mapping]] = ..., actions: _Optional[_Iterable[str]] = ..., aux_data: _Optional[_Union[AuxData, _Mapping]] = ...) -> None: ...

class CheckOutput(_message.Message):
    __slots__ = ["request_id", "resource_id", "actions", "effective_derived_roles", "validation_errors", "outputs"]
    class ActionEffect(_message.Message):
        __slots__ = ["effect", "policy", "scope"]
        EFFECT_FIELD_NUMBER: _ClassVar[int]
        POLICY_FIELD_NUMBER: _ClassVar[int]
        SCOPE_FIELD_NUMBER: _ClassVar[int]
        effect: _effect_pb2.Effect
        policy: str
        scope: str
        def __init__(self, effect: _Optional[_Union[_effect_pb2.Effect, str]] = ..., policy: _Optional[str] = ..., scope: _Optional[str] = ...) -> None: ...
    class ActionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: CheckOutput.ActionEffect
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[CheckOutput.ActionEffect, _Mapping]] = ...) -> None: ...
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    EFFECTIVE_DERIVED_ROLES_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_ERRORS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    resource_id: str
    actions: _containers.MessageMap[str, CheckOutput.ActionEffect]
    effective_derived_roles: _containers.RepeatedScalarFieldContainer[str]
    validation_errors: _containers.RepeatedCompositeFieldContainer[_schema_pb2.ValidationError]
    outputs: _containers.RepeatedCompositeFieldContainer[OutputEntry]
    def __init__(self, request_id: _Optional[str] = ..., resource_id: _Optional[str] = ..., actions: _Optional[_Mapping[str, CheckOutput.ActionEffect]] = ..., effective_derived_roles: _Optional[_Iterable[str]] = ..., validation_errors: _Optional[_Iterable[_Union[_schema_pb2.ValidationError, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[OutputEntry, _Mapping]]] = ...) -> None: ...

class OutputEntry(_message.Message):
    __slots__ = ["src", "val"]
    SRC_FIELD_NUMBER: _ClassVar[int]
    VAL_FIELD_NUMBER: _ClassVar[int]
    src: str
    val: _struct_pb2.Value
    def __init__(self, src: _Optional[str] = ..., val: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...

class Resource(_message.Message):
    __slots__ = ["kind", "policy_version", "id", "attr", "scope"]
    class AttrEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    KIND_FIELD_NUMBER: _ClassVar[int]
    POLICY_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ATTR_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    kind: str
    policy_version: str
    id: str
    attr: _containers.MessageMap[str, _struct_pb2.Value]
    scope: str
    def __init__(self, kind: _Optional[str] = ..., policy_version: _Optional[str] = ..., id: _Optional[str] = ..., attr: _Optional[_Mapping[str, _struct_pb2.Value]] = ..., scope: _Optional[str] = ...) -> None: ...

class Principal(_message.Message):
    __slots__ = ["id", "policy_version", "roles", "attr", "scope"]
    class AttrEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    POLICY_VERSION_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    ATTR_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    policy_version: str
    roles: _containers.RepeatedScalarFieldContainer[str]
    attr: _containers.MessageMap[str, _struct_pb2.Value]
    scope: str
    def __init__(self, id: _Optional[str] = ..., policy_version: _Optional[str] = ..., roles: _Optional[_Iterable[str]] = ..., attr: _Optional[_Mapping[str, _struct_pb2.Value]] = ..., scope: _Optional[str] = ...) -> None: ...

class AuxData(_message.Message):
    __slots__ = ["jwt"]
    class JwtEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    JWT_FIELD_NUMBER: _ClassVar[int]
    jwt: _containers.MessageMap[str, _struct_pb2.Value]
    def __init__(self, jwt: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...

class Trace(_message.Message):
    __slots__ = ["components", "event"]
    class Component(_message.Message):
        __slots__ = ["kind", "action", "derived_role", "expr", "index", "policy", "resource", "rule", "scope", "variable", "output"]
        class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            KIND_UNSPECIFIED: _ClassVar[Trace.Component.Kind]
            KIND_ACTION: _ClassVar[Trace.Component.Kind]
            KIND_CONDITION_ALL: _ClassVar[Trace.Component.Kind]
            KIND_CONDITION_ANY: _ClassVar[Trace.Component.Kind]
            KIND_CONDITION_NONE: _ClassVar[Trace.Component.Kind]
            KIND_CONDITION: _ClassVar[Trace.Component.Kind]
            KIND_DERIVED_ROLE: _ClassVar[Trace.Component.Kind]
            KIND_EXPR: _ClassVar[Trace.Component.Kind]
            KIND_POLICY: _ClassVar[Trace.Component.Kind]
            KIND_RESOURCE: _ClassVar[Trace.Component.Kind]
            KIND_RULE: _ClassVar[Trace.Component.Kind]
            KIND_SCOPE: _ClassVar[Trace.Component.Kind]
            KIND_VARIABLE: _ClassVar[Trace.Component.Kind]
            KIND_VARIABLES: _ClassVar[Trace.Component.Kind]
            KIND_OUTPUT: _ClassVar[Trace.Component.Kind]
        KIND_UNSPECIFIED: Trace.Component.Kind
        KIND_ACTION: Trace.Component.Kind
        KIND_CONDITION_ALL: Trace.Component.Kind
        KIND_CONDITION_ANY: Trace.Component.Kind
        KIND_CONDITION_NONE: Trace.Component.Kind
        KIND_CONDITION: Trace.Component.Kind
        KIND_DERIVED_ROLE: Trace.Component.Kind
        KIND_EXPR: Trace.Component.Kind
        KIND_POLICY: Trace.Component.Kind
        KIND_RESOURCE: Trace.Component.Kind
        KIND_RULE: Trace.Component.Kind
        KIND_SCOPE: Trace.Component.Kind
        KIND_VARIABLE: Trace.Component.Kind
        KIND_VARIABLES: Trace.Component.Kind
        KIND_OUTPUT: Trace.Component.Kind
        class Variable(_message.Message):
            __slots__ = ["name", "expr"]
            NAME_FIELD_NUMBER: _ClassVar[int]
            EXPR_FIELD_NUMBER: _ClassVar[int]
            name: str
            expr: str
            def __init__(self, name: _Optional[str] = ..., expr: _Optional[str] = ...) -> None: ...
        KIND_FIELD_NUMBER: _ClassVar[int]
        ACTION_FIELD_NUMBER: _ClassVar[int]
        DERIVED_ROLE_FIELD_NUMBER: _ClassVar[int]
        EXPR_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        POLICY_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_FIELD_NUMBER: _ClassVar[int]
        RULE_FIELD_NUMBER: _ClassVar[int]
        SCOPE_FIELD_NUMBER: _ClassVar[int]
        VARIABLE_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_FIELD_NUMBER: _ClassVar[int]
        kind: Trace.Component.Kind
        action: str
        derived_role: str
        expr: str
        index: int
        policy: str
        resource: str
        rule: str
        scope: str
        variable: Trace.Component.Variable
        output: str
        def __init__(self, kind: _Optional[_Union[Trace.Component.Kind, str]] = ..., action: _Optional[str] = ..., derived_role: _Optional[str] = ..., expr: _Optional[str] = ..., index: _Optional[int] = ..., policy: _Optional[str] = ..., resource: _Optional[str] = ..., rule: _Optional[str] = ..., scope: _Optional[str] = ..., variable: _Optional[_Union[Trace.Component.Variable, _Mapping]] = ..., output: _Optional[str] = ...) -> None: ...
    class Event(_message.Message):
        __slots__ = ["status", "effect", "error", "message", "result"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            STATUS_UNSPECIFIED: _ClassVar[Trace.Event.Status]
            STATUS_ACTIVATED: _ClassVar[Trace.Event.Status]
            STATUS_SKIPPED: _ClassVar[Trace.Event.Status]
        STATUS_UNSPECIFIED: Trace.Event.Status
        STATUS_ACTIVATED: Trace.Event.Status
        STATUS_SKIPPED: Trace.Event.Status
        STATUS_FIELD_NUMBER: _ClassVar[int]
        EFFECT_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        status: Trace.Event.Status
        effect: _effect_pb2.Effect
        error: str
        message: str
        result: _struct_pb2.Value
        def __init__(self, status: _Optional[_Union[Trace.Event.Status, str]] = ..., effect: _Optional[_Union[_effect_pb2.Effect, str]] = ..., error: _Optional[str] = ..., message: _Optional[str] = ..., result: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    components: _containers.RepeatedCompositeFieldContainer[Trace.Component]
    event: Trace.Event
    def __init__(self, components: _Optional[_Iterable[_Union[Trace.Component, _Mapping]]] = ..., event: _Optional[_Union[Trace.Event, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/effect/v1/effect.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63\x65rbos/effect/v1/effect.proto\x12\x10\x63\x65rbos.effect.v1*X\n\x06\x45\x66\x66\x65\x63t\x12\x16\n\x12\x45\x46\x46\x45\x43T_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x45\x46\x46\x45\x43T_ALLOW\x10\x01\x12\x0f\n\x0b\x45\x46\x46\x45\x43T_DENY\x10\x02\x12\x13\n\x0f\x45\x46\x46\x45\x43T_NO_MATCH\x10\x03\x42o\n\x18\x64\x65v.cerbos.api.v1.effectZ<github.com/cerbos/cerbos/api/genpb/cerbos/effect/v1;effectv1\xaa\x02\x14\x43\x65rbos.Api.V1.Effectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.effect.v1.effect_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030dev.cerbos.api.v1.effectZ<github.com/cerbos/cerbos/api/genpb/cerbos/effect/v1;effectv1\252\002\024Cerbos.Api.V1.Effect'
  _globals['_EFFECT']._serialized_start=51
  _globals['_EFFECT']._serialized_end=139
# @@protoc_insertion_point(module_scope)



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParsedExpr(_message.Message):
    __slots__ = ["expr", "source_info"]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    SOURCE_INFO_FIELD_NUMBER: _ClassVar[int]
    expr: Expr
    source_info: SourceInfo
    def __init__(self, expr: _Optional[_Union[Expr, _Mapping]] = ..., source_info: _Optional[_Union[SourceInfo, _Mapping]] = ...) -> None: ...

class Expr(_message.Message):
    __slots__ = ["id", "const_expr", "ident_expr", "select_expr", "call_expr", "list_expr", "struct_expr", "comprehension_expr"]
    class Ident(_message.Message):
        __slots__ = ["name"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        name: str
        def __init__(self, name: _Optional[str] = ...) -> None: ...
    class Select(_message.Message):
        __slots__ = ["operand", "field", "test_only"]
        OPERAND_FIELD_NUMBER: _ClassVar[int]
        FIELD_FIELD_NUMBER: _ClassVar[int]
        TEST_ONLY_FIELD_NUMBER: _ClassVar[int]
        operand: Expr
        field: str
        test_only: bool
        def __init__(self, operand: _Optional[_Union[Expr, _Mapping]] = ..., field: _Optional[str] = ..., test_only: bool = ...) -> None: ...
    class Call(_message.Message):
        __slots__ = ["target", "function", "args"]
        TARGET_FIELD_NUMBER: _ClassVar[int]
        FUNCTION_FIELD_NUMBER: _ClassVar[int]
        ARGS_FIELD_NUMBER: _ClassVar[int]
        target: Expr
        function: str
        args: _containers.RepeatedCompositeFieldContainer[Expr]
        def __init__(self, target: _Optional[_Union[Expr, _Mapping]] = ..., function: _Optional[str] = ..., args: _Optional[_Iterable[_Union[Expr, _Mapping]]] = ...) -> None: ...
    class CreateList(_message.Message):
        __slots__ = ["elements", "optional_indices"]
        ELEMENTS_FIELD_NUMBER: _ClassVar[int]
        OPTIONAL_INDICES_FIELD_NUMBER: _ClassVar[int]
        elements: _containers.RepeatedCompositeFieldContainer[Expr]
        optional_indices: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, elements: _Optional[_Iterable[_Union[Expr, _Mapping]]] = ..., optional_indices: _Optional[_Iterable[int]] = ...) -> None: ...
    class CreateStruct(_message.Message):
        __slots__ = ["message_name", "entries"]
        class Entry(_message.Message):
            __slots__ = ["id", "field_key", "map_key", "value", "optional_entry"]
            ID_FIELD_NUMBER: _ClassVar[int]
            FIELD_KEY_FIELD_NUMBER: _ClassVar[int]
            MAP_KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            OPTIONAL_ENTRY_FIELD_NUMBER: _ClassVar[int]
            id: int
            field_key: str
            map_key: Expr
            value: Expr
            optional_entry: bool
            def __init__(self, id: _Optional[int] = ..., field_key: _Optional[str] = ..., map_key: _Optional[_Union[Expr, _Mapping]] = ..., value: _Optional[_Union[Expr, _Mapping]] = ..., optional_entry: bool = ...) -> None: ...
        MESSAGE_NAME_FIELD_NUMBER: _ClassVar[int]
        ENTRIES_FIELD_NUMBER: _ClassVar[int]
        message_name: str
        entries: _containers.RepeatedCompositeFieldContainer[Expr.CreateStruct.Entry]
        def __init__(self, message_name: _Optional[str] = ..., entries: _Optional[_Iterable[_Union[Expr.CreateStruct.Entry, _Mapping]]] = ...) -> None: ...
    class Comprehension(_message.Message):
        __slots__ = ["iter_var", "iter_range", "accu_var", "accu_init", "loop_condition", "loop_step", "result"]
        ITER_VAR_FIELD_NUMBER: _ClassVar[int]
        ITER_RANGE_FIELD_NUMBER: _ClassVar[int]
        ACCU_VAR_FIELD_NUMBER: _ClassVar[int]
        ACCU_INIT_FIELD_NUMBER: _ClassVar[int]
        LOOP_CONDITION_FIELD_NUMBER: _ClassVar[int]
        LOOP_STEP_FIELD_NUMBER: _ClassVar[int]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        iter_var: str
        iter_range: Expr
        accu_var: str
        accu_init: Expr
        loop_condition: Expr
        loop_step: Expr
        result: Expr
        def __init__(self, iter_var: _Optional[str] = ..., iter_range: _Optional[_Union[Expr, _Mapping]] = ..., accu_var: _Optional[str] = ..., accu_init: _Optional[_Union[Expr, _Mapping]] = ..., loop_condition: _Optional[_Union[Expr, _Mapping]] = ..., loop_step: _Optional[_Union[Expr, _Mapping]] = ..., result: _Optional[_Union[Expr, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CONST_EXPR_FIELD_NUMBER: _ClassVar[int]
    IDENT_EXPR_FIELD_NUMBER: _ClassVar[int]
    SELECT_EXPR_FIELD_NUMBER: _ClassVar[int]
    CALL_EXPR_FIELD_NUMBER: _ClassVar[int]
    LIST_EXPR_FIELD_NUMBER: _ClassVar[int]
    STRUCT_EXPR_FIELD_NUMBER: _ClassVar[int]
    COMPREHENSION_EXPR_FIELD_NUMBER: _ClassVar[int]
    id: int
    const_expr: Constant
    ident_expr: Expr.Ident
    select_expr: Expr.Select
    call_expr: Expr.Call
    list_expr: Expr.CreateList
    struct_expr: Expr.CreateStruct
    comprehension_expr: Expr.Comprehension
    def __init__(self, id: _Optional[int] = ..., const_expr: _Optional[_Union[Constant, _Mapping]] = ..., ident_expr: _Optional[_Union[Expr.Ident, _Mapping]] = ..., select_expr: _Optional[_Union[Expr.Select, _Mapping]] = ..., call_expr: _Optional[_Union[Expr.Call, _Mapping]] = ..., list_expr: _Optional[_Union[Expr.CreateList, _Mapping]] = ..., struct_expr: _Optional[_Union[Expr.CreateStruct, _Mapping]] = ..., comprehension_expr: _Optional[_Union[Expr.Comprehension, _Mapping]] = ...) -> None: ...

class Constant(_message.Message):
    __slots__ = ["null_value", "bool_value", "int64_value", "uint64_value", "double_value", "string_value", "bytes_value", "duration_value", "timestamp_value"]
    NULL_VALUE_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    BYTES_VALUE_FIELD_NUMBER: _ClassVar[int]
    DURATION_VALUE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_VALUE_FIELD_NUMBER: _ClassVar[int]
    null_value: _struct_pb2.NullValue
    bool_value: bool
    int64_value: int
    uint64_value: int
    double_value: float
    string_value: str
    bytes_value: bytes
    duration_value: _duration_pb2.Duration
    timestamp_value: _timestamp_pb2.Timestamp
    def __init__(self, null_value: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., bool_value: bool = ..., int64_value: _Optional[int] = ..., uint64_value: _Optional[int] = ..., double_value: _Optional[float] = ..., string_value: _Optional[str] = ..., bytes_value: _Optional[bytes] = ..., duration_value: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., timestamp_value: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SourceInfo(_message.Message):
    __slots__ = ["syntax_version", "location", "line_offsets", "positions", "macro_calls"]
    class PositionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: int
        def __init__(self, key: _Optional[int] = ..., value: _Optional[int] = ...) -> None: ...
    class MacroCallsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: Expr
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[Expr, _Mapping]] = ...) -> None: ...
    SYNTAX_VERSION_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    LINE_OFFSETS_FIELD_NUMBER: _ClassVar[int]
    POSITIONS_FIELD_NUMBER: _ClassVar[int]
    MACRO_CALLS_FIELD_NUMBER: _ClassVar[int]
    syntax_version: str
    location: str
    line_offsets: _containers.RepeatedScalarFieldContainer[int]
    positions: _containers.ScalarMap[int, int]
    macro_calls: _containers.MessageMap[int, Expr]
    def __init__(self, syntax_version: _Optional[str] = ..., location: _Optional[str] = ..., line_offsets: _Optional[_Iterable[int]] = ..., positions: _Optional[_Mapping[int, int]] = ..., macro_calls: _Optional[_Mapping[int, Expr]] = ...) -> None: ...

class SourcePosition(_message.Message):
    __slots__ = ["location", "offset", "line", "column"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LINE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    location: str
    offset: int
    line: int
    column: int
    def __init__(self, location: _Optional[str] = ..., offset: _Optional[int] = ..., line: _Optional[int] = ..., column: _Optional[int] = ...) -> None: ...



from cerbos.effect.v1 import effect_pb2 as _effect_pb2
from cerbos.engine.v1 import engine_pb2 as _engine_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Policy(_message.Message):
    __slots__ = ["api_version", "disabled", "description", "metadata", "resource_policy", "principal_policy", "derived_roles", "export_variables", "variables", "json_schema"]
    class VariablesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    API_VERSION_FIELD_NUMBER: _ClassVar[int]
    DISABLED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_POLICY_FIELD_NUMBER: _ClassVar[int]
    PRINCIPAL_POLICY_FIELD_NUMBER: _ClassVar[int]
    DERIVED_ROLES_FIELD_NUMBER: _ClassVar[int]
    EXPORT_VARIABLES_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    api_version: str
    disabled: bool
    description: str
    metadata: Metadata
    resource_policy: ResourcePolicy
    principal_policy: PrincipalPolicy
    derived_roles: DerivedRoles
    export_variables: ExportVariables
    variables: _containers.ScalarMap[str, str]
    json_schema: str
    def __init__(self, api_version: _Optional[str] = ..., disabled: bool = ..., description: _Optional[str] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ..., resource_policy: _Optional[_Union[ResourcePolicy, _Mapping]] = ..., principal_policy: _Optional[_Union[PrincipalPolicy, _Mapping]] = ..., derived_roles: _Optional[_Union[DerivedRoles, _Mapping]] = ..., export_variables: _Optional[_Union[ExportVariables, _Mapping]] = ..., variables: _Optional[_Mapping[str, str]] = ..., json_schema: _Optional[str] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ["source_file", "annotations", "hash", "store_identifer", "store_identifier"]
    class AnnotationsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SOURCE_FILE_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    STORE_IDENTIFER_FIELD_NUMBER: _ClassVar[int]
    STORE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    source_file: str
    annotations: _containers.ScalarMap[str, str]
    hash: _wrappers_pb2.UInt64Value
    store_identifer: str
    store_identifier: str
    def __init__(self, source_file: _Optional[str] = ..., annotations: _Optional[_Mapping[str, str]] = ..., hash: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., store_identifer: _Optional[str] = ..., store_identifier: _Optional[str] = ...) -> None: ...

class ResourcePolicy(_message.Message):
    __slots__ = ["resource", "version", "import_derived_roles", "rules", "scope", "schemas", "variables"]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    IMPORT_DERIVED_ROLES_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    resource: str
    version: str
    import_derived_roles: _containers.RepeatedScalarFieldContainer[str]
    rules: _containers.RepeatedCompositeFieldContainer[ResourceRule]
    scope: str
    schemas: Schemas
    variables: Variables
    def __init__(self, resource: _Optional[str] = ..., version: _Optional[str] = ..., import_derived_roles: _Optional[_Iterable[str]] = ..., rules: _Optional[_Iterable[_Union[ResourceRule, _Mapping]]] = ..., scope: _Optional[str] = ..., schemas: _Optional[_Union[Schemas, _Mapping]] = ..., variables: _Optional[_Union[Variables, _Mapping]] = ...) -> None: ...

class ResourceRule(_message.Message):
    __slots__ = ["actions", "derived_roles", "roles", "condition", "effect", "name", "output"]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    DERIVED_ROLES_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    EFFECT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    actions: _containers.RepeatedScalarFieldContainer[str]
    derived_roles: _containers.RepeatedScalarFieldContainer[str]
    roles: _containers.RepeatedScalarFieldContainer[str]
    condition: Condition
    effect: _effect_pb2.Effect
    name: str
    output: Output
    def __init__(self, actions: _Optional[_Iterable[str]] = ..., derived_roles: _Optional[_Iterable[str]] = ..., roles: _Optional[_Iterable[str]] = ..., condition: _Optional[_Union[Condition, _Mapping]] = ..., effect: _Optional[_Union[_effect_pb2.Effect, str]] = ..., name: _Optional[str] = ..., output: _Optional[_Union[Output, _Mapping]] = ...) -> None: ...

class PrincipalPolicy(_message.Message):
    __slots__ = ["principal", "version", "rules", "scope", "variables"]
    PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    principal: str
    version: str
    rules: _containers.RepeatedCompositeFieldContainer[PrincipalRule]
    scope: str
    variables: Variables
    def __init__(self, principal: _Optional[str] = ..., version: _Optional[str] = ..., rules: _Optional[_Iterable[_Union[PrincipalRule, _Mapping]]] = ..., scope: _Optional[str] = ..., variables: _Optional[_Union[Variables, _Mapping]] = ...) -> None: ...

class PrincipalRule(_message.Message):
    __slots__ = ["resource", "actions"]
    class Action(_message.Message):
        __slots__ = ["action", "condition", "effect", "name", "output"]
        ACTION_FIELD_NUMBER: _ClassVar[int]
        CONDITION_FIELD_NUMBER: _ClassVar[int]
        EFFECT_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_FIELD_NUMBER: _ClassVar[int]
        action: str
        condition: Condition
        effect: _effect_pb2.Effect
        name: str
        output: Output
        def __init__(self, action: _Optional[str] = ..., condition: _Optional[_Union[Condition, _Mapping]] = ..., effect: _Optional[_Union[_effect_pb2.Effect, str]] = ..., name: _Optional[str] = ..., output: _Optional[_Union[Output, _Mapping]] = ...) -> None: ...
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    ACTIONS_FIELD_NUMBER: _ClassVar[int]
    resource: str
    actions: _containers.RepeatedCompositeFieldContainer[PrincipalRule.Action]
    def __init__(self, resource: _Optional[str] = ..., actions: _Optional[_Iterable[_Union[PrincipalRule.Action, _Mapping]]] = ...) -> None: ...

class DerivedRoles(_message.Message):
    __slots__ = ["name", "definitions", "variables"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    name: str
    definitions: _containers.RepeatedCompositeFieldContainer[RoleDef]
    variables: Variables
    def __init__(self, name: _Optional[str] = ..., definitions: _Optional[_Iterable[_Union[RoleDef, _Mapping]]] = ..., variables: _Optional[_Union[Variables, _Mapping]] = ...) -> None: ...

class RoleDef(_message.Message):
    __slots__ = ["name", "parent_roles", "condition"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARENT_ROLES_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    name: str
    parent_roles: _containers.RepeatedScalarFieldContainer[str]
    condition: Condition
    def __init__(self, name: _Optional[str] = ..., parent_roles: _Optional[_Iterable[str]] = ..., condition: _Optional[_Union[Condition, _Mapping]] = ...) -> None: ...

class ExportVariables(_message.Message):
    __slots__ = ["name", "definitions"]
    class DefinitionsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    definitions: _containers.ScalarMap[str, str]
    def __init__(self, name: _Optional[str] = ..., definitions: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Variables(_message.Message):
    __slots__ = ["local"]
    class LocalEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    IMPORT_FIELD_NUMBER: _ClassVar[int]
    LOCAL_FIELD_NUMBER: _ClassVar[int]
    local: _containers.ScalarMap[str, str]
    def __init__(self, local: _Optional[_Mapping[str, str]] = ..., **kwargs) -> None: ...

class Condition(_message.Message):
    __slots__ = ["match", "script"]
    MATCH_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    match: Match
    script: str
    def __init__(self, match: _Optional[_Union[Match, _Mapping]] = ..., script: _Optional[str] = ...) -> None: ...

class Match(_message.Message):
    __slots__ = ["all", "any", "none", "expr"]
    class ExprList(_message.Message):
        __slots__ = ["of"]
        OF_FIELD_NUMBER: _ClassVar[int]
        of: _containers.RepeatedCompositeFieldContainer[Match]
        def __init__(self, of: _Optional[_Iterable[_Union[Match, _Mapping]]] = ...) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    ANY_FIELD_NUMBER: _ClassVar[int]
    NONE_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    all: Match.ExprList
    any: Match.ExprList
    none: Match.ExprList
    expr: str
    def __init__(self, all: _Optional[_Union[Match.ExprList, _Mapping]] = ..., any: _Optional[_Union[Match.ExprList, _Mapping]] = ..., none: _Optional[_Union[Match.ExprList, _Mapping]] = ..., expr: _Optional[str] = ...) -> None: ...

class Output(_message.Message):
    __slots__ = ["expr"]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: str
    def __init__(self, expr: _Optional[str] = ...) -> None: ...

class Schemas(_message.Message):
    __slots__ = ["principal_schema", "resource_schema"]
    class IgnoreWhen(_message.Message):
        __slots__ = ["actions"]
        ACTIONS_FIELD_NUMBER: _ClassVar[int]
        actions: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, actions: _Optional[_Iterable[str]] = ...) -> None: ...
    class Schema(_message.Message):
        __slots__ = ["ref", "ignore_when"]
        REF_FIELD_NUMBER: _ClassVar[int]
        IGNORE_WHEN_FIELD_NUMBER: _ClassVar[int]
        ref: str
        ignore_when: Schemas.IgnoreWhen
        def __init__(self, ref: _Optional[str] = ..., ignore_when: _Optional[_Union[Schemas.IgnoreWhen, _Mapping]] = ...) -> None: ...
    PRINCIPAL_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    principal_schema: Schemas.Schema
    resource_schema: Schemas.Schema
    def __init__(self, principal_schema: _Optional[_Union[Schemas.Schema, _Mapping]] = ..., resource_schema: _Optional[_Union[Schemas.Schema, _Mapping]] = ...) -> None: ...

class TestFixture(_message.Message):
    __slots__ = []
    class Principals(_message.Message):
        __slots__ = ["principals", "json_schema"]
        class PrincipalsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _engine_pb2.Principal
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.Principal, _Mapping]] = ...) -> None: ...
        PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
        JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
        principals: _containers.MessageMap[str, _engine_pb2.Principal]
        json_schema: str
        def __init__(self, principals: _Optional[_Mapping[str, _engine_pb2.Principal]] = ..., json_schema: _Optional[str] = ...) -> None: ...
    class Resources(_message.Message):
        __slots__ = ["resources", "json_schema"]
        class ResourcesEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _engine_pb2.Resource
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.Resource, _Mapping]] = ...) -> None: ...
        RESOURCES_FIELD_NUMBER: _ClassVar[int]
        JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
        resources: _containers.MessageMap[str, _engine_pb2.Resource]
        json_schema: str
        def __init__(self, resources: _Optional[_Mapping[str, _engine_pb2.Resource]] = ..., json_schema: _Optional[str] = ...) -> None: ...
    class AuxData(_message.Message):
        __slots__ = ["aux_data", "json_schema"]
        class AuxDataEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _engine_pb2.AuxData
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.AuxData, _Mapping]] = ...) -> None: ...
        AUX_DATA_FIELD_NUMBER: _ClassVar[int]
        JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
        aux_data: _containers.MessageMap[str, _engine_pb2.AuxData]
        json_schema: str
        def __init__(self, aux_data: _Optional[_Mapping[str, _engine_pb2.AuxData]] = ..., json_schema: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class TestOptions(_message.Message):
    __slots__ = ["now"]
    NOW_FIELD_NUMBER: _ClassVar[int]
    now: _timestamp_pb2.Timestamp
    def __init__(self, now: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TestSuite(_message.Message):
    __slots__ = ["name", "description", "skip", "skip_reason", "tests", "principals", "resources", "aux_data", "options", "json_schema"]
    class PrincipalsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _engine_pb2.Principal
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.Principal, _Mapping]] = ...) -> None: ...
    class ResourcesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _engine_pb2.Resource
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.Resource, _Mapping]] = ...) -> None: ...
    class AuxDataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _engine_pb2.AuxData
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_engine_pb2.AuxData, _Mapping]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    SKIP_REASON_FIELD_NUMBER: _ClassVar[int]
    TESTS_FIELD_NUMBER: _ClassVar[int]
    PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    AUX_DATA_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    skip: bool
    skip_reason: str
    tests: _containers.RepeatedCompositeFieldContainer[TestTable]
    principals: _containers.MessageMap[str, _engine_pb2.Principal]
    resources: _containers.MessageMap[str, _engine_pb2.Resource]
    aux_data: _containers.MessageMap[str, _engine_pb2.AuxData]
    options: TestOptions
    json_schema: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., skip: bool = ..., skip_reason: _Optional[str] = ..., tests: _Optional[_Iterable[_Union[TestTable, _Mapping]]] = ..., principals: _Optional[_Mapping[str, _engine_pb2.Principal]] = ..., resources: _Optional[_Mapping[str, _engine_pb2.Resource]] = ..., aux_data: _Optional[_Mapping[str, _engine_pb2.AuxData]] = ..., options: _Optional[_Union[TestOptions, _Mapping]] = ..., json_schema: _Optional[str] = ...) -> None: ...

class TestTable(_message.Message):
    __slots__ = ["name", "description", "skip", "skip_reason", "input", "expected", "options"]
    class Input(_message.Message):
        __slots__ = ["principals", "resources", "actions", "aux_data"]
        PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
        RESOURCES_FIELD_NUMBER: _ClassVar[int]
        ACTIONS_FIELD_NUMBER: _ClassVar[int]
        AUX_DATA_FIELD_NUMBER: _ClassVar[int]
        principals: _containers.RepeatedScalarFieldContainer[str]
        resources: _containers.RepeatedScalarFieldContainer[str]
        actions: _containers.RepeatedScalarFieldContainer[str]
        aux_data: str
        def __init__(self, principals: _Optional[_Iterable[str]] = ..., resources: _Optional[_Iterable[str]] = ..., actions: _Optional[_Iterable[str]] = ..., aux_data: _Optional[str] = ...) -> None: ...
    class OutputExpectations(_message.Message):
        __slots__ = ["action", "expected"]
        ACTION_FIELD_NUMBER: _ClassVar[int]
        EXPECTED_FIELD_NUMBER: _ClassVar[int]
        action: str
        expected: _containers.RepeatedCompositeFieldContainer[_engine_pb2.OutputEntry]
        def __init__(self, action: _Optional[str] = ..., expected: _Optional[_Iterable[_Union[_engine_pb2.OutputEntry, _Mapping]]] = ...) -> None: ...
    class Expectation(_message.Message):
        __slots__ = ["principal", "resource", "actions", "outputs"]
        class ActionsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _effect_pb2.Effect
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_effect_pb2.Effect, str]] = ...) -> None: ...
        PRINCIPAL_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_FIELD_NUMBER: _ClassVar[int]
        ACTIONS_FIELD_NUMBER: _ClassVar[int]
        OUTPUTS_FIELD_NUMBER: _ClassVar[int]
        principal: str
        resource: str
        actions: _containers.ScalarMap[str, _effect_pb2.Effect]
        outputs: _containers.RepeatedCompositeFieldContainer[TestTable.OutputExpectations]
        def __init__(self, principal: _Optional[str] = ..., resource: _Optional[str] = ..., actions: _Optional[_Mapping[str, _effect_pb2.Effect]] = ..., outputs: _Optional[_Iterable[_Union[TestTable.OutputExpectations, _Mapping]]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    SKIP_REASON_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    skip: bool
    skip_reason: str
    input: TestTable.Input
    expected: _containers.RepeatedCompositeFieldContainer[TestTable.Expectation]
    options: TestOptions
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., skip: bool = ..., skip_reason: _Optional[str] = ..., input: _Optional[_Union[TestTable.Input, _Mapping]] = ..., expected: _Optional[_Iterable[_Union[TestTable.Expectation, _Mapping]]] = ..., options: _Optional[_Union[TestOptions, _Mapping]] = ...) -> None: ...

class Test(_message.Message):
    __slots__ = ["name", "description", "skip", "skip_reason", "input", "expected", "options", "expected_outputs"]
    class TestName(_message.Message):
        __slots__ = ["test_table_name", "principal_key", "resource_key"]
        TEST_TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
        PRINCIPAL_KEY_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_KEY_FIELD_NUMBER: _ClassVar[int]
        test_table_name: str
        principal_key: str
        resource_key: str
        def __init__(self, test_table_name: _Optional[str] = ..., principal_key: _Optional[str] = ..., resource_key: _Optional[str] = ...) -> None: ...
    class OutputEntries(_message.Message):
        __slots__ = ["entries"]
        class EntriesEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _struct_pb2.Value
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
        ENTRIES_FIELD_NUMBER: _ClassVar[int]
        entries: _containers.MessageMap[str, _struct_pb2.Value]
        def __init__(self, entries: _Optional[_Mapping[str, _struct_pb2.Value]] = ...) -> None: ...
    class ExpectedEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _effect_pb2.Effect
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_effect_pb2.Effect, str]] = ...) -> None: ...
    class ExpectedOutputsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Test.OutputEntries
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Test.OutputEntries, _Mapping]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    SKIP_REASON_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    name: Test.TestName
    description: str
    skip: bool
    skip_reason: str
    input: _engine_pb2.CheckInput
    expected: _containers.ScalarMap[str, _effect_pb2.Effect]
    options: TestOptions
    expected_outputs: _containers.MessageMap[str, Test.OutputEntries]
    def __init__(self, name: _Optional[_Union[Test.TestName, _Mapping]] = ..., description: _Optional[str] = ..., skip: bool = ..., skip_reason: _Optional[str] = ..., input: _Optional[_Union[_engine_pb2.CheckInput, _Mapping]] = ..., expected: _Optional[_Mapping[str, _effect_pb2.Effect]] = ..., options: _Optional[_Union[TestOptions, _Mapping]] = ..., expected_outputs: _Optional[_Mapping[str, Test.OutputEntries]] = ...) -> None: ...

class TestResults(_message.Message):
    __slots__ = ["suites", "summary"]
    class Result(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        RESULT_UNSPECIFIED: _ClassVar[TestResults.Result]
        RESULT_SKIPPED: _ClassVar[TestResults.Result]
        RESULT_PASSED: _ClassVar[TestResults.Result]
        RESULT_FAILED: _ClassVar[TestResults.Result]
        RESULT_ERRORED: _ClassVar[TestResults.Result]
    RESULT_UNSPECIFIED: TestResults.Result
    RESULT_SKIPPED: TestResults.Result
    RESULT_PASSED: TestResults.Result
    RESULT_FAILED: TestResults.Result
    RESULT_ERRORED: TestResults.Result
    class Tally(_message.Message):
        __slots__ = ["result", "count"]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        COUNT_FIELD_NUMBER: _ClassVar[int]
        result: TestResults.Result
        count: int
        def __init__(self, result: _Optional[_Union[TestResults.Result, str]] = ..., count: _Optional[int] = ...) -> None: ...
    class Summary(_message.Message):
        __slots__ = ["overall_result", "tests_count", "result_counts"]
        OVERALL_RESULT_FIELD_NUMBER: _ClassVar[int]
        TESTS_COUNT_FIELD_NUMBER: _ClassVar[int]
        RESULT_COUNTS_FIELD_NUMBER: _ClassVar[int]
        overall_result: TestResults.Result
        tests_count: int
        result_counts: _containers.RepeatedCompositeFieldContainer[TestResults.Tally]
        def __init__(self, overall_result: _Optional[_Union[TestResults.Result, str]] = ..., tests_count: _Optional[int] = ..., result_counts: _Optional[_Iterable[_Union[TestResults.Tally, _Mapping]]] = ...) -> None: ...
    class Suite(_message.Message):
        __slots__ = ["file", "name", "principals", "summary", "error", "test_cases", "description"]
        FILE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        TEST_CASES_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        file: str
        name: str
        principals: _containers.RepeatedCompositeFieldContainer[TestResults.Principal]
        summary: TestResults.Summary
        error: str
        test_cases: _containers.RepeatedCompositeFieldContainer[TestResults.TestCase]
        description: str
        def __init__(self, file: _Optional[str] = ..., name: _Optional[str] = ..., principals: _Optional[_Iterable[_Union[TestResults.Principal, _Mapping]]] = ..., summary: _Optional[_Union[TestResults.Summary, _Mapping]] = ..., error: _Optional[str] = ..., test_cases: _Optional[_Iterable[_Union[TestResults.TestCase, _Mapping]]] = ..., description: _Optional[str] = ...) -> None: ...
    class TestCase(_message.Message):
        __slots__ = ["name", "principals"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PRINCIPALS_FIELD_NUMBER: _ClassVar[int]
        name: str
        principals: _containers.RepeatedCompositeFieldContainer[TestResults.Principal]
        def __init__(self, name: _Optional[str] = ..., principals: _Optional[_Iterable[_Union[TestResults.Principal, _Mapping]]] = ...) -> None: ...
    class Principal(_message.Message):
        __slots__ = ["name", "resources"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        RESOURCES_FIELD_NUMBER: _ClassVar[int]
        name: str
        resources: _containers.RepeatedCompositeFieldContainer[TestResults.Resource]
        def __init__(self, name: _Optional[str] = ..., resources: _Optional[_Iterable[_Union[TestResults.Resource, _Mapping]]] = ...) -> None: ...
    class Resource(_message.Message):
        __slots__ = ["name", "actions"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        ACTIONS_FIELD_NUMBER: _ClassVar[int]
        name: str
        actions: _containers.RepeatedCompositeFieldContainer[TestResults.Action]
        def __init__(self, name: _Optional[str] = ..., actions: _Optional[_Iterable[_Union[TestResults.Action, _Mapping]]] = ...) -> None: ...
    class Action(_message.Message):
        __slots__ = ["name", "details"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DETAILS_FIELD_NUMBER: _ClassVar[int]
        name: str
        details: TestResults.Details
        def __init__(self, name: _Optional[str] = ..., details: _Optional[_Union[TestResults.Details, _Mapping]] = ...) -> None: ...
    class Details(_message.Message):
        __slots__ = ["result", "failure", "error", "engine_trace"]
        RESULT_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        ERROR_FIELD_NUMBER: _ClassVar[int]
        ENGINE_TRACE_FIELD_NUMBER: _ClassVar[int]
        result: TestResults.Result
        failure: TestResults.Failure
        error: str
        engine_trace: _containers.RepeatedCompositeFieldContainer[_engine_pb2.Trace]
        def __init__(self, result: _Optional[_Union[TestResults.Result, str]] = ..., failure: _Optional[_Union[TestResults.Failure, _Mapping]] = ..., error: _Optional[str] = ..., engine_trace: _Optional[_Iterable[_Union[_engine_pb2.Trace, _Mapping]]] = ...) -> None: ...
    class OutputFailure(_message.Message):
        __slots__ = ["src", "mismatched", "missing"]
        class MismatchedValue(_message.Message):
            __slots__ = ["expected", "actual"]
            EXPECTED_FIELD_NUMBER: _ClassVar[int]
            ACTUAL_FIELD_NUMBER: _ClassVar[int]
            expected: _struct_pb2.Value
            actual: _struct_pb2.Value
            def __init__(self, expected: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ..., actual: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
        class MissingValue(_message.Message):
            __slots__ = ["expected"]
            EXPECTED_FIELD_NUMBER: _ClassVar[int]
            expected: _struct_pb2.Value
            def __init__(self, expected: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...) -> None: ...
        SRC_FIELD_NUMBER: _ClassVar[int]
        MISMATCHED_FIELD_NUMBER: _ClassVar[int]
        MISSING_FIELD_NUMBER: _ClassVar[int]
        src: str
        mismatched: TestResults.OutputFailure.MismatchedValue
        missing: TestResults.OutputFailure.MissingValue
        def __init__(self, src: _Optional[str] = ..., mismatched: _Optional[_Union[TestResults.OutputFailure.MismatchedValue, _Mapping]] = ..., missing: _Optional[_Union[TestResults.OutputFailure.MissingValue, _Mapping]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ["expected", "actual", "outputs"]
        EXPECTED_FIELD_NUMBER: _ClassVar[int]
        ACTUAL_FIELD_NUMBER: _ClassVar[int]
        OUTPUTS_FIELD_NUMBER: _ClassVar[int]
        expected: _effect_pb2.Effect
        actual: _effect_pb2.Effect
        outputs: _containers.RepeatedCompositeFieldContainer[TestResults.OutputFailure]
        def __init__(self, expected: _Optional[_Union[_effect_pb2.Effect, str]] = ..., actual: _Optional[_Union[_effect_pb2.Effect, str]] = ..., outputs: _Optional[_Iterable[_Union[TestResults.OutputFailure, _Mapping]]] = ...) -> None: ...
    SUITES_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    suites: _containers.RepeatedCompositeFieldContainer[TestResults.Suite]
    summary: TestResults.Summary
    def __init__(self, suites: _Optional[_Iterable[_Union[TestResults.Suite, _Mapping]]] = ..., summary: _Optional[_Union[TestResults.Summary, _Mapping]] = ...) -> None: ...



from google.api.expr.v1alpha1 import syntax_pb2 as _syntax_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CheckedExpr(_message.Message):
    __slots__ = ["reference_map", "type_map", "source_info", "expr_version", "expr"]
    class ReferenceMapEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: Reference
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...
    class TypeMapEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: Type
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...
    REFERENCE_MAP_FIELD_NUMBER: _ClassVar[int]
    TYPE_MAP_FIELD_NUMBER: _ClassVar[int]
    SOURCE_INFO_FIELD_NUMBER: _ClassVar[int]
    EXPR_VERSION_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    reference_map: _containers.MessageMap[int, Reference]
    type_map: _containers.MessageMap[int, Type]
    source_info: _syntax_pb2.SourceInfo
    expr_version: str
    expr: _syntax_pb2.Expr
    def __init__(self, reference_map: _Optional[_Mapping[int, Reference]] = ..., type_map: _Optional[_Mapping[int, Type]] = ..., source_info: _Optional[_Union[_syntax_pb2.SourceInfo, _Mapping]] = ..., expr_version: _Optional[str] = ..., expr: _Optional[_Union[_syntax_pb2.Expr, _Mapping]] = ...) -> None: ...

class Type(_message.Message):
    __slots__ = ["dyn", "null", "primitive", "wrapper", "well_known", "list_type", "map_type", "function", "message_type", "type_param", "type", "error", "abstract_type"]
    class PrimitiveType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        PRIMITIVE_TYPE_UNSPECIFIED: _ClassVar[Type.PrimitiveType]
        BOOL: _ClassVar[Type.PrimitiveType]
        INT64: _ClassVar[Type.PrimitiveType]
        UINT64: _ClassVar[Type.PrimitiveType]
        DOUBLE: _ClassVar[Type.PrimitiveType]
        STRING: _ClassVar[Type.PrimitiveType]
        BYTES: _ClassVar[Type.PrimitiveType]
    PRIMITIVE_TYPE_UNSPECIFIED: Type.PrimitiveType
    BOOL: Type.PrimitiveType
    INT64: Type.PrimitiveType
    UINT64: Type.PrimitiveType
    DOUBLE: Type.PrimitiveType
    STRING: Type.PrimitiveType
    BYTES: Type.PrimitiveType
    class WellKnownType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        WELL_KNOWN_TYPE_UNSPECIFIED: _ClassVar[Type.WellKnownType]
        ANY: _ClassVar[Type.WellKnownType]
        TIMESTAMP: _ClassVar[Type.WellKnownType]
        DURATION: _ClassVar[Type.WellKnownType]
    WELL_KNOWN_TYPE_UNSPECIFIED: Type.WellKnownType
    ANY: Type.WellKnownType
    TIMESTAMP: Type.WellKnownType
    DURATION: Type.WellKnownType
    class ListType(_message.Message):
        __slots__ = ["elem_type"]
        ELEM_TYPE_FIELD_NUMBER: _ClassVar[int]
        elem_type: Type
        def __init__(self, elem_type: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...
    class MapType(_message.Message):
        __slots__ = ["key_type", "value_type"]
        KEY_TYPE_FIELD_NUMBER: _ClassVar[int]
        VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
        key_type: Type
        value_type: Type
        def __init__(self, key_type: _Optional[_Union[Type, _Mapping]] = ..., value_type: _Optional[_Union[Type, _Mapping]] = ...) -> None: ...
    class FunctionType(_message.Message):
        __slots__ = ["result_type", "arg_types"]
        RESULT_TYPE_FIELD_NUMBER: _ClassVar[int]
        ARG_TYPES_FIELD_NUMBER: _ClassVar[int]
        result_type: Type
        arg_types: _containers.RepeatedCompositeFieldContainer[Type]
        def __init__(self, result_type: _Optional[_Union[Type, _Mapping]] = ..., arg_types: _Optional[_Iterable[_Union[Type, _Mapping]]] = ...) -> None: ...
    class AbstractType(_message.Message):
        __slots__ = ["name", "parameter_types"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PARAMETER_TYPES_FIELD_NUMBER: _ClassVar[int]
        name: str
        parameter_types: _containers.RepeatedCompositeFieldContainer[Type]
        def __init__(self, name: _Optional[str] = ..., parameter_types: _Optional[_Iterable[_Union[Type, _Mapping]]] = ...) -> None: ...
    DYN_FIELD_NUMBER: _ClassVar[int]
    NULL_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_FIELD_NUMBER: _ClassVar[int]
    WRAPPER_FIELD_NUMBER: _ClassVar[int]
    WELL_KNOWN_FIELD_NUMBER: _ClassVar[int]
    LIST_TYPE_FIELD_NUMBER: _ClassVar[int]
    MAP_TYPE_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPE_PARAM_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ABSTRACT_TYPE_FIELD_NUMBER: _ClassVar[int]
    dyn: _empty_pb2.Empty
    null: _struct_pb2.NullValue
    primitive: Type.PrimitiveType
    wrapper: Type.PrimitiveType
    well_known: Type.WellKnownType
    list_type: Type.ListType
    map_type: Type.MapType
    function: Type.FunctionType
    message_type: str
    type_param: str
    type: Type
    error: _empty_pb2.Empty
    abstract_type: Type.AbstractType
    def __init__(self, dyn: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., null: _Optional[_Union[_struct_pb2.NullValue, str]] = ..., primitive: _Optional[_Union[Type.PrimitiveType, str]] = ..., wrapper: _Optional[_Union[Type.PrimitiveType, str]] = ..., well_known: _Optional[_Union[Type.WellKnownType, str]] = ..., list_type: _Optional[_Union[Type.ListType, _Mapping]] = ..., map_type: _Optional[_Union[Type.MapType, _Mapping]] = ..., function: _Optional[_Union[Type.FunctionType, _Mapping]] = ..., message_type: _Optional[str] = ..., type_param: _Optional[str] = ..., type: _Optional[_Union[Type, _Mapping]] = ..., error: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., abstract_type: _Optional[_Union[Type.AbstractType, _Mapping]] = ...) -> None: ...

class Decl(_message.Message):
    __slots__ = ["name", "ident", "function"]
    class IdentDecl(_message.Message):
        __slots__ = ["type", "value", "doc"]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        DOC_FIELD_NUMBER: _ClassVar[int]
        type: Type
        value: _syntax_pb2.Constant
        doc: str
        def __init__(self, type: _Optional[_Union[Type, _Mapping]] = ..., value: _Optional[_Union[_syntax_pb2.Constant, _Mapping]] = ..., doc: _Optional[str] = ...) -> None: ...
    class FunctionDecl(_message.Message):
        __slots__ = ["overloads"]
        class Overload(_message.Message):
            __slots__ = ["overload_id", "params", "type_params", "result_type", "is_instance_function", "doc"]
            OVERLOAD_ID_FIELD_NUMBER: _ClassVar[int]
            PARAMS_FIELD_NUMBER: _ClassVar[int]
            TYPE_PARAMS_FIELD_NUMBER: _ClassVar[int]
            RESULT_TYPE_FIELD_NUMBER: _ClassVar[int]
            IS_INSTANCE_FUNCTION_FIELD_NUMBER: _ClassVar[int]
            DOC_FIELD_NUMBER: _ClassVar[int]
            overload_id: str
            params: _containers.RepeatedCompositeFieldContainer[Type]
            type_params: _containers.RepeatedScalarFieldContainer[str]
            result_type: Type
            is_instance_function: bool
            doc: str
            def __init__(self, overload_id: _Optional[str] = ..., params: _Optional[_Iterable[_Union[Type, _Mapping]]] = ..., type_params: _Optional[_Iterable[str]] = ..., result_type: _Optional[_Union[Type, _Mapping]] = ..., is_instance_function: bool = ..., doc: _Optional[str] = ...) -> None: ...
        OVERLOADS_FIELD_NUMBER: _ClassVar[int]
        overloads: _containers.RepeatedCompositeFieldContainer[Decl.FunctionDecl.Overload]
        def __init__(self, overloads: _Optional[_Iterable[_Union[Decl.FunctionDecl.Overload, _Mapping]]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    IDENT_FIELD_NUMBER: _ClassVar[int]
    FUNCTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    ident: Decl.IdentDecl
    function: Decl.FunctionDecl
    def __init__(self, name: _Optional[str] = ..., ident: _Optional[_Union[Decl.IdentDecl, _Mapping]] = ..., function: _Optional[_Union[Decl.FunctionDecl, _Mapping]] = ...) -> None: ...

class Reference(_message.Message):
    __slots__ = ["name", "overload_id", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OVERLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    overload_id: _containers.RepeatedScalarFieldContainer[str]
    value: _syntax_pb2.Constant
    def __init__(self, name: _Optional[str] = ..., overload_id: _Optional[_Iterable[str]] = ..., value: _Optional[_Union[_syntax_pb2.Constant, _Mapping]] = ...) -> None: ...



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServerLaunch(_message.Message):
    __slots__ = ["version", "source", "features", "stats"]
    class Cerbos(_message.Message):
        __slots__ = ["version", "commit", "build_date", "module_version", "module_checksum"]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        COMMIT_FIELD_NUMBER: _ClassVar[int]
        BUILD_DATE_FIELD_NUMBER: _ClassVar[int]
        MODULE_VERSION_FIELD_NUMBER: _ClassVar[int]
        MODULE_CHECKSUM_FIELD_NUMBER: _ClassVar[int]
        version: str
        commit: str
        build_date: str
        module_version: str
        module_checksum: str
        def __init__(self, version: _Optional[str] = ..., commit: _Optional[str] = ..., build_date: _Optional[str] = ..., module_version: _Optional[str] = ..., module_checksum: _Optional[str] = ...) -> None: ...
    class Source(_message.Message):
        __slots__ = ["cerbos", "os", "arch", "num_cpus"]
        CERBOS_FIELD_NUMBER: _ClassVar[int]
        OS_FIELD_NUMBER: _ClassVar[int]
        ARCH_FIELD_NUMBER: _ClassVar[int]
        NUM_CPUS_FIELD_NUMBER: _ClassVar[int]
        cerbos: ServerLaunch.Cerbos
        os: str
        arch: str
        num_cpus: int
        def __init__(self, cerbos: _Optional[_Union[ServerLaunch.Cerbos, _Mapping]] = ..., os: _Optional[str] = ..., arch: _Optional[str] = ..., num_cpus: _Optional[int] = ...) -> None: ...
    class Features(_message.Message):
        __slots__ = ["audit", "schema", "admin_api", "storage"]
        class Audit(_message.Message):
            __slots__ = ["enabled", "backend"]
            ENABLED_FIELD_NUMBER: _ClassVar[int]
            BACKEND_FIELD_NUMBER: _ClassVar[int]
            enabled: bool
            backend: str
            def __init__(self, enabled: bool = ..., backend: _Optional[str] = ...) -> None: ...
        class Schema(_message.Message):
            __slots__ = ["enforcement"]
            ENFORCEMENT_FIELD_NUMBER: _ClassVar[int]
            enforcement: str
            def __init__(self, enforcement: _Optional[str] = ...) -> None: ...
        class AdminApi(_message.Message):
            __slots__ = ["enabled"]
            ENABLED_FIELD_NUMBER: _ClassVar[int]
            enabled: bool
            def __init__(self, enabled: bool = ...) -> None: ...
        class Storage(_message.Message):
            __slots__ = ["driver", "disk", "git", "blob", "bundle"]
            class Disk(_message.Message):
                __slots__ = ["watch"]
                WATCH_FIELD_NUMBER: _ClassVar[int]
                watch: bool
                def __init__(self, watch: bool = ...) -> None: ...
            class Git(_message.Message):
                __slots__ = ["protocol", "auth", "poll_interval"]
                PROTOCOL_FIELD_NUMBER: _ClassVar[int]
                AUTH_FIELD_NUMBER: _ClassVar[int]
                POLL_INTERVAL_FIELD_NUMBER: _ClassVar[int]
                protocol: str
                auth: bool
                poll_interval: _duration_pb2.Duration
                def __init__(self, protocol: _Optional[str] = ..., auth: bool = ..., poll_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
            class Blob(_message.Message):
                __slots__ = ["provider", "poll_interval"]
                PROVIDER_FIELD_NUMBER: _ClassVar[int]
                POLL_INTERVAL_FIELD_NUMBER: _ClassVar[int]
                provider: str
                poll_interval: _duration_pb2.Duration
                def __init__(self, provider: _Optional[str] = ..., poll_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
            class Bundle(_message.Message):
                __slots__ = ["pdp_id", "bundle_source", "client_id"]
                PDP_ID_FIELD_NUMBER: _ClassVar[int]
                BUNDLE_SOURCE_FIELD_NUMBER: _ClassVar[int]
                CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
                pdp_id: str
                bundle_source: str
                client_id: str
                def __init__(self, pdp_id: _Optional[str] = ..., bundle_source: _Optional[str] = ..., client_id: _Optional[str] = ...) -> None: ...
            DRIVER_FIELD_NUMBER: _ClassVar[int]
            DISK_FIELD_NUMBER: _ClassVar[int]
            GIT_FIELD_NUMBER: _ClassVar[int]
            BLOB_FIELD_NUMBER: _ClassVar[int]
            BUNDLE_FIELD_NUMBER: _ClassVar[int]
            driver: str
            disk: ServerLaunch.Features.Storage.Disk
            git: ServerLaunch.Features.Storage.Git
            blob: ServerLaunch.Features.Storage.Blob
            bundle: ServerLaunch.Features.Storage.Bundle
            def __init__(self, driver: _Optional[str] = ..., disk: _Optional[_Union[ServerLaunch.Features.Storage.Disk, _Mapping]] = ..., git: _Optional[_Union[ServerLaunch.Features.Storage.Git, _Mapping]] = ..., blob: _Optional[_Union[ServerLaunch.Features.Storage.Blob, _Mapping]] = ..., bundle: _Optional[_Union[ServerLaunch.Features.Storage.Bundle, _Mapping]] = ...) -> None: ...
        AUDIT_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_FIELD_NUMBER: _ClassVar[int]
        ADMIN_API_FIELD_NUMBER: _ClassVar[int]
        STORAGE_FIELD_NUMBER: _ClassVar[int]
        audit: ServerLaunch.Features.Audit
        schema: ServerLaunch.Features.Schema
        admin_api: ServerLaunch.Features.AdminApi
        storage: ServerLaunch.Features.Storage
        def __init__(self, audit: _Optional[_Union[ServerLaunch.Features.Audit, _Mapping]] = ..., schema: _Optional[_Union[ServerLaunch.Features.Schema, _Mapping]] = ..., admin_api: _Optional[_Union[ServerLaunch.Features.AdminApi, _Mapping]] = ..., storage: _Optional[_Union[ServerLaunch.Features.Storage, _Mapping]] = ...) -> None: ...
    class Stats(_message.Message):
        __slots__ = ["policy", "schema"]
        class Policy(_message.Message):
            __slots__ = ["count", "avg_rule_count", "avg_condition_count"]
            class CountEntry(_message.Message):
                __slots__ = ["key", "value"]
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: int
                def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
            class AvgRuleCountEntry(_message.Message):
                __slots__ = ["key", "value"]
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: float
                def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
            class AvgConditionCountEntry(_message.Message):
                __slots__ = ["key", "value"]
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: float
                def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
            COUNT_FIELD_NUMBER: _ClassVar[int]
            AVG_RULE_COUNT_FIELD_NUMBER: _ClassVar[int]
            AVG_CONDITION_COUNT_FIELD_NUMBER: _ClassVar[int]
            count: _containers.ScalarMap[str, int]
            avg_rule_count: _containers.ScalarMap[str, float]
            avg_condition_count: _containers.ScalarMap[str, float]
            def __init__(self, count: _Optional[_Mapping[str, int]] = ..., avg_rule_count: _Optional[_Mapping[str, float]] = ..., avg_condition_count: _Optional[_Mapping[str, float]] = ...) -> None: ...
        class Schema(_message.Message):
            __slots__ = ["count"]
            COUNT_FIELD_NUMBER: _ClassVar[int]
            count: int
            def __init__(self, count: _Optional[int] = ...) -> None: ...
        POLICY_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_FIELD_NUMBER: _ClassVar[int]
        policy: ServerLaunch.Stats.Policy
        schema: ServerLaunch.Stats.Schema
        def __init__(self, policy: _Optional[_Union[ServerLaunch.Stats.Policy, _Mapping]] = ..., schema: _Optional[_Union[ServerLaunch.Stats.Schema, _Mapping]] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    version: str
    source: ServerLaunch.Source
    features: ServerLaunch.Features
    stats: ServerLaunch.Stats
    def __init__(self, version: _Optional[str] = ..., source: _Optional[_Union[ServerLaunch.Source, _Mapping]] = ..., features: _Optional[_Union[ServerLaunch.Features, _Mapping]] = ..., stats: _Optional[_Union[ServerLaunch.Stats, _Mapping]] = ...) -> None: ...

class ServerStop(_message.Message):
    __slots__ = ["version", "uptime", "requests_total"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UPTIME_FIELD_NUMBER: _ClassVar[int]
    REQUESTS_TOTAL_FIELD_NUMBER: _ClassVar[int]
    version: str
    uptime: _duration_pb2.Duration
    requests_total: int
    def __init__(self, version: _Optional[str] = ..., uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., requests_total: _Optional[int] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ["api_activity"]
    class CountStat(_message.Message):
        __slots__ = ["key", "count"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        COUNT_FIELD_NUMBER: _ClassVar[int]
        key: str
        count: int
        def __init__(self, key: _Optional[str] = ..., count: _Optional[int] = ...) -> None: ...
    class ApiActivity(_message.Message):
        __slots__ = ["version", "uptime", "method_calls", "user_agents"]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        UPTIME_FIELD_NUMBER: _ClassVar[int]
        METHOD_CALLS_FIELD_NUMBER: _ClassVar[int]
        USER_AGENTS_FIELD_NUMBER: _ClassVar[int]
        version: str
        uptime: _duration_pb2.Duration
        method_calls: _containers.RepeatedCompositeFieldContainer[Event.CountStat]
        user_agents: _containers.RepeatedCompositeFieldContainer[Event.CountStat]
        def __init__(self, version: _Optional[str] = ..., uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., method_calls: _Optional[_Iterable[_Union[Event.CountStat, _Mapping]]] = ..., user_agents: _Optional[_Iterable[_Union[Event.CountStat, _Mapping]]] = ...) -> None: ...
    API_ACTIVITY_FIELD_NUMBER: _ClassVar[int]
    api_activity: Event.ApiActivity
    def __init__(self, api_activity: _Optional[_Union[Event.ApiActivity, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/checked.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/api/expr/v1alpha1/checked.proto\x12\x18google.api.expr.v1alpha1\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x9a\x04\n\x0b\x43heckedExpr\x12\\\n\rreference_map\x18\x02 \x03(\x0b\x32\x37.google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntryR\x0creferenceMap\x12M\n\x08type_map\x18\x03 \x03(\x0b\x32\x32.google.api.expr.v1alpha1.CheckedExpr.TypeMapEntryR\x07typeMap\x12\x45\n\x0bsource_info\x18\x05 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfoR\nsourceInfo\x12!\n\x0c\x65xpr_version\x18\x06 \x01(\tR\x0b\x65xprVersion\x12\x32\n\x04\x65xpr\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprR\x04\x65xpr\x1a\x64\n\x11ReferenceMapEntry\x12\x10\n\x03key\x18\x01 \x01(\x03R\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.ReferenceR\x05value:\x02\x38\x01\x1aZ\n\x0cTypeMapEntry\x12\x10\n\x03key\x18\x01 \x01(\x03R\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x05value:\x02\x38\x01\"\xc8\x0b\n\x04Type\x12*\n\x03\x64yn\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x03\x64yn\x12\x30\n\x04null\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00R\x04null\x12L\n\tprimitive\x18\x03 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00R\tprimitive\x12H\n\x07wrapper\x18\x04 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00R\x07wrapper\x12M\n\nwell_known\x18\x05 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.WellKnownTypeH\x00R\twellKnown\x12\x46\n\tlist_type\x18\x06 \x01(\x0b\x32\'.google.api.expr.v1alpha1.Type.ListTypeH\x00R\x08listType\x12\x43\n\x08map_type\x18\x07 \x01(\x0b\x32&.google.api.expr.v1alpha1.Type.MapTypeH\x00R\x07mapType\x12I\n\x08\x66unction\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.FunctionTypeH\x00R\x08\x66unction\x12#\n\x0cmessage_type\x18\t \x01(\tH\x00R\x0bmessageType\x12\x1f\n\ntype_param\x18\n \x01(\tH\x00R\ttypeParam\x12\x34\n\x04type\x18\x0b \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeH\x00R\x04type\x12.\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x05\x65rror\x12R\n\rabstract_type\x18\x0e \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.AbstractTypeH\x00R\x0c\x61\x62stractType\x1aG\n\x08ListType\x12;\n\telem_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x08\x65lemType\x1a\x83\x01\n\x07MapType\x12\x39\n\x08key_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x07keyType\x12=\n\nvalue_type\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\tvalueType\x1a\x8c\x01\n\x0c\x46unctionType\x12?\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\nresultType\x12;\n\targ_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x08\x61rgTypes\x1ak\n\x0c\x41\x62stractType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12G\n\x0fparameter_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x0eparameterTypes\"s\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\n\n\x06UINT64\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x12\n\n\x06STRING\x10\x05\x12\t\n\x05\x42YTES\x10\x06\"V\n\rWellKnownType\x12\x1f\n\x1bWELL_KNOWN_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\r\n\tTIMESTAMP\x10\x02\x12\x0c\n\x08\x44URATION\x10\x03\x42\x0b\n\ttype_kind\"\xb3\x05\n\x04\x44\x65\x63l\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12@\n\x05ident\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.Decl.IdentDeclH\x00R\x05ident\x12I\n\x08\x66unction\x18\x03 \x01(\x0b\x32+.google.api.expr.v1alpha1.Decl.FunctionDeclH\x00R\x08\x66unction\x1a\x8b\x01\n\tIdentDecl\x12\x32\n\x04type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x04type\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantR\x05value\x12\x10\n\x03\x64oc\x18\x03 \x01(\tR\x03\x64oc\x1a\xee\x02\n\x0c\x46unctionDecl\x12R\n\toverloads\x18\x01 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.Decl.FunctionDecl.OverloadR\toverloads\x1a\x89\x02\n\x08Overload\x12\x1f\n\x0boverload_id\x18\x01 \x01(\tR\noverloadId\x12\x36\n\x06params\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\x06params\x12\x1f\n\x0btype_params\x18\x03 \x03(\tR\ntypeParams\x12?\n\x0bresult_type\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeR\nresultType\x12\x30\n\x14is_instance_function\x18\x05 \x01(\x08R\x12isInstanceFunction\x12\x10\n\x03\x64oc\x18\x06 \x01(\tR\x03\x64ocB\x0b\n\tdecl_kind\"z\n\tReference\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x0boverload_id\x18\x03 \x03(\tR\noverloadId\x12\x38\n\x05value\x18\x04 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantR\x05valueBl\n\x1c\x63om.google.api.expr.v1alpha1B\tDeclProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.checked_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\tDeclProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _CHECKEDEXPR_REFERENCEMAPENTRY._options = None
  _CHECKEDEXPR_REFERENCEMAPENTRY._serialized_options = b'8\001'
  _CHECKEDEXPR_TYPEMAPENTRY._options = None
  _CHECKEDEXPR_TYPEMAPENTRY._serialized_options = b'8\001'
  _globals['_CHECKEDEXPR']._serialized_start=167
  _globals['_CHECKEDEXPR']._serialized_end=705
  _globals['_CHECKEDEXPR_REFERENCEMAPENTRY']._serialized_start=513
  _globals['_CHECKEDEXPR_REFERENCEMAPENTRY']._serialized_end=613
  _globals['_CHECKEDEXPR_TYPEMAPENTRY']._serialized_start=615
  _globals['_CHECKEDEXPR_TYPEMAPENTRY']._serialized_end=705
  _globals['_TYPE']._serialized_start=708
  _globals['_TYPE']._serialized_end=2188
  _globals['_TYPE_LISTTYPE']._serialized_start=1513
  _globals['_TYPE_LISTTYPE']._serialized_end=1584
  _globals['_TYPE_MAPTYPE']._serialized_start=1587
  _globals['_TYPE_MAPTYPE']._serialized_end=1718
  _globals['_TYPE_FUNCTIONTYPE']._serialized_start=1721
  _globals['_TYPE_FUNCTIONTYPE']._serialized_end=1861
  _globals['_TYPE_ABSTRACTTYPE']._serialized_start=1863
  _globals['_TYPE_ABSTRACTTYPE']._serialized_end=1970
  _globals['_TYPE_PRIMITIVETYPE']._serialized_start=1972
  _globals['_TYPE_PRIMITIVETYPE']._serialized_end=2087
  _globals['_TYPE_WELLKNOWNTYPE']._serialized_start=2089
  _globals['_TYPE_WELLKNOWNTYPE']._serialized_end=2175
  _globals['_DECL']._serialized_start=2191
  _globals['_DECL']._serialized_end=2882
  _globals['_DECL_IDENTDECL']._serialized_start=2361
  _globals['_DECL_IDENTDECL']._serialized_end=2500
  _globals['_DECL_FUNCTIONDECL']._serialized_start=2503
  _globals['_DECL_FUNCTIONDECL']._serialized_end=2869
  _globals['_DECL_FUNCTIONDECL_OVERLOAD']._serialized_start=2604
  _globals['_DECL_FUNCTIONDECL_OVERLOAD']._serialized_end=2869
  _globals['_REFERENCE']._serialized_start=2884
  _globals['_REFERENCE']._serialized_end=3006
# @@protoc_insertion_point(module_scope)
